rpc_dart_log library

Client-side library for rpc_dart_log.

Import this in your Flutter/Dart app to stream logs to a log collector:

import 'package:rpc_dart_log/rpc_dart_log.dart';

final controller = LogController(
  outputs: [
    ConsoleOutput(),
    LogCollectorOutput(
      uri: Uri.parse('ws://192.168.1.10:9500'),
      device: DeviceInfo(name: 'iPhone 15', app: 'MyApp'),
    ),
  ],
);

Classes

DeviceInfo
Device information sent by the client during handshake.
LogCollectorOutput
A LogOutput that sends log records to a remote logCollector collector over WebSocket using rpc_dart contracts.