LogCollectorConsole class
Terminal renderer for logCollector. Prints tagged log records with device labels and ANSI colors.
Constructors
- LogCollectorConsole({bool colored = true, IOSink? sink})
-
sinkdefaults to stdout. Use stderr when running alongside MCP.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printConnection(
LogCollectorConnectionEvent event) → void - Print a connection event.
-
printRecord(
TaggedRecord tagged) → void - Print a tagged log record.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited