LogCollectorSession class
A connected client session.
Constructors
- LogCollectorSession({required int id, required String deviceName, required String app, DateTime? connectedAt})
Properties
- app → String
-
Application name.
final
- connectedAt → DateTime
-
When the client connected.
final
- deviceName → String
-
Device name received from the handshake.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Unique session identifier.
final
- label → String
-
Short label used in log output.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited